==> haskell-mwc-random-0.15.2.0-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mwc-random
version:              0.15.2.0
visibility:           public
id:                   mwc-random-0.15.2.0-Fp2MkpA1RoeCuAP2jEN3RB
key:                  mwc-random-0.15.2.0-Fp2MkpA1RoeCuAP2jEN3RB
license:              BSD-2-Clause
copyright:            2009, 2010, 2011 Bryan O'\''Sullivan
maintainer:           Alexey Khudyakov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/mwc-random
synopsis:             Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.

category:             Math, Statistics
abi:                  584c676af4213978874a190b1f8b003c
exposed:              True
exposed-modules:
    System.Random.MWC System.Random.MWC.CondensedTable
    System.Random.MWC.Distributions System.Random.MWC.SeedSource

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mwc-random-0.15.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mwc-random-0.15.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mwc-random-0.15.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mwc-random
hs-libraries:         HSmwc-random-0.15.2.0-Fp2MkpA1RoeCuAP2jEN3RB
depends:
    base-4.17.2.1 math-functions-0.3.4.4-9Ei3GQZ6egPDOS4kMeuiZo
    primitive-0.9.1.0-3qHntBOAe4Y4he61Fs3OAc
    random-1.2.1.3-ddmLWvz8i69p1T3sgcHVE time-1.12.2
    vector-0.13.2.0-K0fBmK5qd7y3388236ZS0A

haddock-interfaces:   /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html:         /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mwc-random-0.15.2.0-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mwc-random
version:              0.15.2.0
visibility:           public
id:                   mwc-random-0.15.2.0-ELj4qUiZnLmAQm95Zp4Gs6
key:                  mwc-random-0.15.2.0-ELj4qUiZnLmAQm95Zp4Gs6
license:              BSD-2-Clause
copyright:            2009, 2010, 2011 Bryan O'\''Sullivan
maintainer:           Alexey Khudyakov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/mwc-random
synopsis:             Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.

category:             Math, Statistics
abi:                  c75c256ac6f6fcb2a4f034af1b771462
exposed:              True
exposed-modules:
    System.Random.MWC System.Random.MWC.CondensedTable
    System.Random.MWC.Distributions System.Random.MWC.SeedSource

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mwc-random-0.15.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mwc-random-0.15.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mwc-random-0.15.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mwc-random
hs-libraries:         HSmwc-random-0.15.2.0-ELj4qUiZnLmAQm95Zp4Gs6
depends:
    base-4.17.2.1 math-functions-0.3.4.4-8WYQ9Gwa2KTIjVDBL6fW9e
    primitive-0.9.1.0-2rF1KRuV9tjItame9gIzcT
    random-1.2.1.3-7QJJoQOVHAI1PeONmcyhZ time-1.12.2
    vector-0.13.2.0-L6HpF7nmtGm1K7R40olL6U

haddock-interfaces:   /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html:         /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
